@@ -76,7 +76,7 @@ map.tail = function(x, interval, inverse = FALSE) {
 knitr::include_graphics("fig_distribution1.png")
 
 ## -----------------------------------------------------------------------------
-n = 300
+n = 1000
 x = rnorm(n) # we generate values for x from a N(0,1) dist.
 eta.x = 1 + 0.4*x
 
@@ -133,7 +133,6 @@ control.bgev = list(q.location = p.alpha,
                     # Hard-coded for the moment: s1=s2=5
                     beta.ab = 5)
 
-
 ## -----------------------------------------------------------------------------
 null.matrix = matrix(nrow = n, ncol= 0)
 spread.x = null.matrix
@@ -150,6 +149,7 @@ r1 = inla(formula,
          control.family = list(hyper = hyper.bgev,
                                control.bgev = control.bgev),
          control.predictor = list(compute = TRUE),
+	     control.fixed = list(prec=100),
          control.compute = list(cpo = TRUE),
          control.inla = list(int.strategy = "eb"),
          verbose=FALSE)
@@ -159,14 +159,14 @@ round(r1$summary.fixed,4)
 round(r1$summary.hyperpar,4)
 
 ## -----------------------------------------------------------------------------
-n = 300
+n = 1000
 x1 = rnorm(n)
 eta.x = 1 + 0.4*x1
 
 ## -----------------------------------------------------------------------------
 x2 = rnorm(n)
 s.x = exp(0.1 + 0.3*x2)
-x3 = runif(n,-0.5,2)
+x3 = runif(n,-0.25,1)
 t.x = 0.1 + 0.2*x3
 tail.intern = map.tail(t.x, tail.interval, inverse=TRUE) # internal xi
 
@@ -204,6 +204,7 @@ r2 = inla(formula,
          control.family = list(hyper = hyper.bgev,
                                control.bgev = control.bgev),
          control.predictor = list(compute = TRUE),
+	     control.fixed = list(prec=100),
          control.compute = list(cpo = TRUE),
          control.inla = list(int.strategy = "eb"),
          verbose=FALSE)
@@ -214,7 +215,7 @@ round(r2$summary.fixed,4)
 round(r2$summary.hyperpar,4)
 
 ## ---- eval = T----------------------------------------------------------------
-n = 300
+n = 1000
 x1 = rnorm(n)
 z1 = seq(0, 6, length.out = n)
 z2 = 1:n
@@ -223,7 +224,6 @@ pacf = runif(p)
 phi = inla.ar.pacf2phi(pacf)
 eta.x = 1 + 0.4*x + sin(z1) + c(scale(arima.sim(n, model = list(ar = phi))))
 
-
 ## -----------------------------------------------------------------------------
 x2 = rnorm(n)
 x4 = rnorm(n)
@@ -256,7 +256,11 @@ tail.x = x3
 # With this change of variable it is easier to keep track of the effect 
 # of the covariates in each parameter, but it is not needed.
 formula = inla.mdata(y, cbind(spread.x, spread.xx), tail.x) ~ 1 + intercept + x + 
-          f(z1, model = "rw1") + f(z2, model = 'ar', order = 2)
+	f(z1, model = "rw1", scale.model=TRUE, 
+		hyper = list(prec = list(prior = "pc.prec", param = c(0.1,
+		0.01)))) +
+		f(z2, model = 'ar', order = 2)
+
 data.bgev = data.frame(y = y, intercept = 1, x = x, z1 = z1, z2 = z2,
                        spread.x = spread.x, spread.xx = spread.xx, tail.x = tail.x)
 r3 = inla(formula,
@@ -265,6 +269,7 @@ r3 = inla(formula,
          control.family = list(hyper = hyper.bgev,
                                control.bgev = control.bgev),
          control.predictor = list(compute = TRUE),
+	     control.fixed = list(prec=100),
          control.compute = list(cpo = TRUE),
          control.inla = list(int.strategy = "eb"),
          verbose=FALSE)
