@@ -2,12 +2,16 @@
 set.seed(123)
 library(INLA)
 set.seed(123)
+INLA:::inla.my.update()
+INLA:::inla.my.update()
+inla.setOption(inla.call="inla.mkl.work")
+
 inla.setOption(num.threads="1:1")
 inla.setOption(smtp="taucs")
 library(knitr)
 library(rmarkdown)
-knitr::opts_chunk$set(echo=TRUE, cache=FALSE, message=FALSE,
-warning=FALSE)
+knitr::opts_chunk$set(echo=TRUE, cache=FALSE, message=FALSE,warning=FALSE)
+knitr::opts_chunk$set(fig.path="figures/conditional-logit/")
 
 ## ----formula, include=TRUE,eval=F---------------------------------------------
 #  fisher.dat <- readRDS(system.file("demodata/data_fisher2.rds", package
